@@ -25,8 +25,12 @@
 #' containing both the component number and internal ID (within the component).
 #'
 #' @param x A `ped` object. Most of these functions also accepts ped lists.
-#' @param neworder A permutation of `labels(x)` or of vector `1:pedsize(x)`. By
-#'   default, the sorting order of the ID labels is used.
+#' @param neworder A permutation of `labels(x)` (or a subset of this),
+#'   indicating the new internal ordering. If `internal = TRUE`, `neworder`
+#'   refers to the internal ordering, so must be numeric. `1:pedsize(x)`. By
+#'   default, the natural order of the ID labels is used.
+#' @param internal A logical (default: FALSE). If TRUE, `neworder` is
+#'   interpreted as referring to the internal ordering.
 #' @param ids A character vector (or coercible to one) of original ID labels.
 #' @param errorIfUnknown A logical. If TRUE (default), the function stops with
 #'   an error if not all elements of `ids` are recognised as names of members in
@@ -38,25 +42,32 @@
 #' x = ped(id = 3:1, fid = c(1,0,0), mid = c(2,0,0), sex = c(1,2,1), reorder = FALSE)
 #' x
 #'
-#' # The 'ids' argument is converted to character, hence these are equivalent:
+#' # The 'ids' argument is converted to character, hence these are the same:
 #' internalID(x, ids = 3)
 #' internalID(x, ids = "3")
 #'
 #' hasParentsBeforeChildren(x)
 #'
-#' # Fix the ordering
-#' y = parentsBeforeChildren(x)
-#' internalID(y, ids = 3)
+#' # Put parents first
+#' parentsBeforeChildren(x)
 #'
-#' # A different ordering
-#' reorderPed(x, c(2,1,3))
+#' # Typical use of reorderPed: Swap sibling plot order
+#' y = nuclearPed(2) |> reorderPed(4:3)
+#' plot(y)
+#'
+#'
+#' ### If labels are numeric, argument `internal` is important
+#' z = singleton(1) |> addParents(1)
+#' z
+#' reorderPed(z, 1:3, internal = FALSE) # ID order = "1","2","3"
+#' reorderPed(z, 1:3, internal = TRUE)  # index order: 1,2,3 (i.e., no change)
 #'
 #' @name ped_internal
 NULL
 
 #' @rdname ped_internal
 #' @export
-reorderPed = function(x, neworder = NULL) {
+reorderPed = function(x, neworder = NULL, internal = FALSE) {
   if(is.pedList(x))
     stop2("Input is a ped list; reordering can only be done for a single component")
   if(!is.ped(x))
@@ -65,24 +76,42 @@ reorderPed = function(x, neworder = NULL) {
     return(x)
 
   if(is.null(neworder)) {
-    if(hasNumLabs(x))
-      neworder = order(as.numeric(labels(x)))
-    else
-      neworder = order(labels(x))
+    orderby = if(hasNumLabs(x)) as.numeric(labels(x)) else labels(x)
+    neworder = order(orderby)
+    internal = TRUE
   }
 
   N = pedsize(x)
-  if(length(neworder) != N)
-    stop2("`neworder` must have length ", N, ", not ", length(neworder))
-  if(!setequal(neworder, labels(x)) && !setequal(neworder, 1:N))
-    stop2("`neworder` must be a permutation of either `labels(x)` or `1:pedsize(x)`: ", neworder)
+  if(anyDuplicated.default(neworder))
+    stop2("Duplicated element of `neworder`: ", neworder(duplicated(neworder)))
+
+  if(internal && !is.numeric(neworder))
+    stop2("When `internal = TRUE`, `neworder` must be numeric: ", class(neworder)[1])
+
+  # If not character, but not explicitly internal: interpret as labels if it makes sense
+  if(!is.character(neworder) && !internal && all(neworder %in% x$ID))
+    neworder = as.character(neworder)
+
+  # Convert to internal indices
   if(is.character(neworder))
-    neworder = internalID(x, neworder)
+    neworder = internalID(x, neworder, errorIfUnknown = TRUE)
+
+  ### By now: neworder assumed numeric with internal ordering
+
+  if(!all(neworder %in% 1:N)) #
+    stop2("Unknown index: ", .mysetdiff(neworder, 1:N))
 
   # If same order, return unchanged
   if(isTRUE(all.equal(neworder, 1:N)))
     return(x)
 
+  # If subset of 1:N, expand:
+  if(length(neworder) < N) {
+    newo = neworder
+    neworder = 1:N
+    neworder[sort.int(newo, method = "quick")] = newo
+  }
+
   # Convert to matrix with attributes
   xmatr = as.matrix(x)
   attr = attributes(xmatr)
@@ -117,7 +146,7 @@ parentsBeforeChildren = function(x) {
     }
     else i = i + 1
   }
-  reorderPed(x, neworder)
+  reorderPed(x, neworder, internal = TRUE)
 }
 
 #' @rdname ped_internal
@@ -150,7 +179,7 @@ foundersFirst = function(x) {
     return(x)
 
   nonfou = nonfounders(x, internal = TRUE)
-  reorderPed(x, neworder = c(fou, nonfou))
+  reorderPed(x, neworder = c(fou, nonfou), internal = TRUE)
 }
 
 
